import React, { useState, useEffect } from "react";
import { Disclosure } from "@headlessui/react";
import { OpenDisclosure, CloseDisclosure } from "@/components/Icons";
import FormCheck from "@/components/CheckBoxComponent/FormCheck";
import axios from "axios";
import { toast } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";

export const ElectronicTab = () => {
  const [consentData, setConsentData] = useState({
    consentTerms: false,
    consentTaxNotification: false,
  });

  const [consentId, setConsentId] = useState(null);

  useEffect(() => {
    const fetchConsent = async () => {
      try {
        const response = await axios.get(
          `${process.env.NEXT_PUBLIC_BASE_URL}/electronicConsent/66878ffd55c588b565f21684`
        );
        setConsentData(response.data);
        setConsentId(response.data._id);
      } catch (error) {
        console.error("Error fetching consent:", error);
      }
    };

    fetchConsent();
  }, []);

  const handleChange = (e) => {
    const { name, checked } = e.target;
    setConsentData((prevData) => ({
      ...prevData,
      [name]: checked,
    }));
  };

  const handleSave = async () => {
    try {
      if (consentId) {
        await axios.patch(
          `${process.env.NEXT_PUBLIC_BASE_URL}/electronicConsent/update/${consentId}`,
          consentData
        );
        toast.success("Consent updated successfully");
      } else {
        const response = await axios.post(
          `${process.env.NEXT_PUBLIC_BASE_URL}/electronicConsent/add`,
          consentData
        );
        toast.success("Consent created successfully");
        setConsentId(response.data._id);
      }
    } catch (error) {
      toast.error(error.response?.data?.error || "Something went wrong");
    }
  };

  return (
    <>
      <span className="text-lg text-prussianBlue/40 mb-4 block">
        Electronic Consent
      </span>
      <div className="custom-shadow rounded flex flex-col gap-2">
        <Disclosure as="div" className={`disclosure`} defaultOpen={true}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Electronic Consent
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="gap-4 px-8 py-6">
                <p className="text-base mb-10">
                  {
                    "By continuing to use our platform, you indicate your acceptance of our terms and conditions. Before continuing, kindly review our terms and conditions document thoroughly. Furthermore, if any transaction entails cross-border purchases that require notification to relevant tax authorities, it is incumbent upon you to provide them with the appropriate information. Neglecting to do so could potentially lead to legal ramifications. By selecting the following boxes, you indicate your acceptance of the following terms:"
                  }
                </p>
                <div className="mb-5 ps-5 flex flex-col gap-2 items-start py-3 font-medium">
                  <FormCheck
                    id="1"
                    label="I agree to abide by the terms and conditions of this transaction."
                    name="consentTerms"
                    checked={consentData.consentTerms}
                    onChange={handleChange}
                  />
                  <FormCheck
                    id="2"
                    label="I acknowledge that if this transaction involves cross-border purchases, it is my responsibility to notify the relevant tax authorities, and I accept accountability for any consequences resulting from failure to do so."
                    name="consentTaxNotification"
                    checked={consentData.consentTaxNotification}
                    onChange={handleChange}
                  />
                </div>
                <div className="custom-shadow px-5 py-3 flex gap-2">
                  <div className="flex justify-center items-center h-3 w-3 shrink-0 border border-darkGray mt-1">
                    <span className="bg-black h-[6px] w-[6px]"></span>
                  </div>
                  <p>
                    {
                      "Note: Failure to check both boxes will result in the inability to use our platform for this transaction. Please ensure both boxes are checked before proceeding."
                    }
                  </p>
                </div>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <div className="flex justify-end gap-3 me-10 my-3">
          <button className="flex justify-center border border-reefGold py-2 px-8 focus:outline-none text-lg font-medium rounded">
            Cancel
          </button>
          <button
            onClick={handleSave}
            className="flex text-white justify-center btn-gradient border-0 py-2 px-10 focus:outline-none text-lg font-medium rounded"
          >
            Save
          </button>
        </div>
      </div>
    </>
  );
};
